@@ -1,17 +1,15 @@
 package KCWin;
-#: Version: 2.0.0
+#: Version: 3.0.0
 #: Description: Creates general-purpose windows with an input and output area
 #: Author: Eduardo M Kalinowski
-#
-# $Id: KCWin.pl 1014 2009-02-01 12:46:52Z ekalin $
 
 BEGIN {
-  eval "use Gtk2";
-  die "This plugin requires the gtk2-perl bindings" if $@;
+  eval "use Gtk3";
+  die "This plugin requires the gtk3-perl bindings" if $@;
 }
 
 
-use base 'Gtk2::Window';
+use base 'Gtk3::Window';
 
 
 sub help {
@@ -22,24 +20,24 @@ nothing by themselves, but they can be used by other plugins when they
 need a window for input and output. The output area supports ANSI
 colors and thus is like a mini MUD window.
 
-    Use KCWin->new to create a new window. KCWin derives from Gtk2::Window
+    Use KCWin->new to create a new window. KCWin derives from Gtk3::Window
 so you can use all of its methods.
 
     The widgets are accessible for customization. If $kcw is a KCWin, the
 following widgets are available:
 
-- $kcw->{VBOX}, Gtk2::VBox, the vertical box that contains the output and
+- $kcw->{VBOX}, Gtk3::Box, the vertical box that contains the output and
   input areas.
-- $kcw->{SCROLLWIN}, Gtk2::ScrolledWindow, this holds the TextView that
+- $kcw->{SCROLLWIN}, Gtk3::ScrolledWindow, this holds the TextView that
   is used for output.
-- $kcw->{TEXTVIEW}, Gtk2::TextView, is the widget used for output.
-- $kcw->{TEXTBUFFER}, Gtk2::TextBuffer, for convenience, the TextBuffer
+- $kcw->{TEXTVIEW}, Gtk3::TextView, is the widget used for output.
+- $kcw->{TEXTBUFFER}, Gtk3::TextBuffer, for convenience, the TextBuffer
   displayed in the window.
-- $kcw->{CMDAREA}, Gtk2::HBox, a box that holds a button to clear the
+- $kcw->{CMDAREA}, Gtk3::Box, a box that holds a button to clear the
   input area, and the input area itself.
-- $kcw->{BTNCLEAR}, Gtk2::Button, a button that clears the input entry
+- $kcw->{BTNCLEAR}, Gtk3::Button, a button that clears the input entry
   widget when clicked.
-- $kcw->{ENTRY}, Gtk2::Entry, the input entry widget. Connect to the
+- $kcw->{ENTRY}, Gtk3::Entry, the input entry widget. Connect to the
   activate signal of this widget to do something when the user presses
   ENTER in this widget.
 
