@@ -1,9 +1,7 @@
 package chat;
-#: Version: 1.0.1
+#: Version: 2.0.0
 #: Description: Chat directly to other people
 #: Author: Eduardo M Kalinowski
-#
-# $Id: chat.pl 1014 2009-02-01 12:46:52Z ekalin $
 
 BEGIN {
   $::world->requireplugin('KCWin');
@@ -460,11 +458,11 @@ sub sendfile {
   }
 
   if (!$file) {
-    my $dialog = Gtk2::FileChooserDialog->new('Select file',
+    my $dialog = Gtk3::FileChooserDialog->new('Select file',
                                               undef,
                                               'open',
-                                              'gtk-cancel' => 'cancel',
-                                              'gtk-ok'     => 'accept');
+                                              '_Cancel' => 'cancel',
+                                              '_Open'   => 'accept');
     my $response = $dialog->run();
     $dialog->hide();
     return if ($response ne 'accept');
@@ -862,7 +860,7 @@ sub receive_establishment_data_ready_cb {
       }
     } else {                      # Second line
       unless ($auto_accept_calls) {
-        my $dialog = Gtk2::MessageDialog->new(undef,
+        my $dialog = Gtk3::MessageDialog->new(undef,
                                               [],
                                               'question',
                                               'yes-no',
@@ -1415,7 +1413,7 @@ sub receive_file {
 
   my ($file, $length) = split(",", $data);
 
-  my $dialog = Gtk2::MessageDialog->new(undef,
+  my $dialog = Gtk3::MessageDialog->new(undef,
                                         [],
                                         'question',
                                         'yes-no',
@@ -1430,11 +1428,11 @@ sub receive_file {
     return;
   }
 
-  $dialog = Gtk2::FileChooserDialog->new('Save file as',
+  $dialog = Gtk3::FileChooserDialog->new('Save file as',
                                          undef,
                                          'save',
-                                         'gtk-cancel' => 'cancel',
-                                         'gtk-save'   => 'accept');
+                                         '_Cancel' => 'cancel',
+                                         '_Save'   => 'accept');
   $dialog->set_current_name($file);
   $response = $dialog->run();
   $dialog->hide();
