@@ -1,13 +1,11 @@
 package notes;
-#: Version: 1.0.0
-#: Description: Assing notes to worlds
+#: Version: 2.0.0
+#: Description: Assign notes to worlds
 #: Author: Eduardo M Kalinowski
-#
-# $Id: notes.pl 1014 2009-02-01 12:46:52Z ekalin $
 
 BEGIN {
-  eval "use Gtk2 -init;";
-  die "This plugin requires the gtk-perl bindings" if $@;
+  eval "use Gtk3 -init;";
+  die "This plugin requires the gtk3-perl bindings" if $@;
 }
 
 $::world->makepermanent('$notes::notetext');
@@ -68,7 +66,7 @@ sub UNLOAD {
 
 
 sub create_window {
-  $window = Gtk2::Window->new;
+  $window = Gtk3::Window->new;
   $window->set_title("Notes for " . $::world->getname());
   $window->signal_connect(delete_event => sub {
                             update_text();
@@ -79,12 +77,12 @@ sub create_window {
                             update_text();
                           });
 
-  my $vbox = Gtk2::VBox->new;
+  my $vbox = Gtk3::VBox->new;
 
-  my $scroll_win = Gtk2::ScrolledWindow->new;
+  my $scroll_win = Gtk3::ScrolledWindow->new;
   $scroll_win->set_policy('never', 'always');
 
-  my $text_view = Gtk2::TextView->new;
+  my $text_view = Gtk3::TextView->new;
   $text_view->set_size_request(400, 150);
   $text_buffer = $text_view->get_buffer;
   update_text_view();
@@ -92,7 +90,7 @@ sub create_window {
   $scroll_win->add($text_view);
   $vbox->pack_start($scroll_win, 1, 1, 0);
 
-  my $btn_close = Gtk2::Button->new_from_stock('gtk-close');
+  my $btn_close = Gtk3::Button->new_with_mnemonic('_Close');
   $btn_close->signal_connect(clicked => sub {
                                update_text();
                                $window->hide;
