@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2025 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,7 +61,7 @@ static AV     *perl_clone_array(AV *orig);
 static void    perl_copy_array(AV *source, AV *dest);
 static SV     *create_window_var(void);
 static World  *fetch_world(int items, SV *self_ref, HV **self_to_store);
-static void    xs_init();
+static void    xs_init(pTHX);
 static int     world_name_comparer(const World *world, const char *name);
 static GSList *get_object_numbers(GSList     *list,
                                   const char *name,
@@ -107,7 +107,7 @@ init_perl_script(World *world)
   SV *window_ref;
   SV *window_var;
 
-  my_argv = g_malloc(sizeof(char *) * (my_argc_static + 2));
+  my_argv = g_malloc(sizeof(char *) * (my_argc_static + 3));
   for (my_argc = 0; my_argc < my_argc_static; ++my_argc) {
     my_argv[my_argc] = my_argv_static[my_argc];
   }
@@ -3629,7 +3629,7 @@ XS__markpluginenadis(pTHX_ CV *perlcv)
 
 static
 void
-xs_init()
+xs_init(pTHX)
 {
   /* This is for dynamic loading of modules */
   char *file = __FILE__;
