@@ -98,6 +98,9 @@ struct _SimoComboBoxPrivate {
 static GtkBinClass *parent_class = NULL;
 static guint        combo_box_signals[LAST_SIGNAL] = {0, };
 
+/* Minimal width for the entry box */
+#define MINIMUM_WIDTH 200
+
 
 static void     simo_combo_box_class_init(SimoComboBoxClass *klass);
 static void     simo_combo_box_init(SimoComboBox *combo_box);
@@ -122,7 +125,8 @@ static void     simo_combo_box_get_preferred_width(GtkWidget *widget,
                                                    gint      *minimum_width,
                                                    gint      *natural_width);
 static void     simo_combo_box_size_request(GtkWidget      *widget,
-                                            GtkRequisition *requisition);
+                                            GtkRequisition *minimum,
+                                            GtkRequisition *natural);
 static gint     simo_combo_box_get_line_height(SimoComboBox *combo_box);
 static void     simo_combo_box_size_allocate(GtkWidget     *widget,
                                              GtkAllocation *allocation);
@@ -593,11 +597,11 @@ simo_combo_box_get_preferred_height(GtkWidget *widget,
                                     gint      *minimum_height,
                                     gint      *natural_height)
 {
-  GtkRequisition req;
+  GtkRequisition minimum, natural;
 
-  simo_combo_box_size_request(widget, &req);
-  *minimum_height = req.height;
-  *natural_height = req.height;
+  simo_combo_box_size_request(widget, &minimum, &natural);
+  *minimum_height = minimum.height;
+  *natural_height = natural.height;
 }
 
 
@@ -607,17 +611,19 @@ simo_combo_box_get_preferred_width(GtkWidget *widget,
                                    gint      *minimum_width,
                                    gint      *natural_width)
 {
-  GtkRequisition req;
+  GtkRequisition minimum, natural;
 
-  simo_combo_box_size_request(widget, &req);
-  *minimum_width = req.width;
-  *natural_width = req.width;
+  simo_combo_box_size_request(widget, &minimum, &natural);
+  *minimum_width = minimum.width;
+  *natural_width = natural.width;
 }
 
 
 static
 void
-simo_combo_box_size_request(GtkWidget *widget, GtkRequisition *req)
+simo_combo_box_size_request(GtkWidget *widget,
+                            GtkRequisition *minimum,
+                            GtkRequisition *natural)
 {
   SimoComboBox *combo_box = SIMO_COMBO_BOX(widget);
   GtkRequisition breq, ereq, areq;
@@ -633,14 +639,17 @@ simo_combo_box_size_request(GtkWidget *widget, GtkRequisition *req)
   ereq.height = breq.height;
 
   if (combo_box->priv->n_lines > 1) {
-    req->height = simo_combo_box_get_line_height(combo_box) * combo_box->priv->n_lines + 8;
+    natural->height = simo_combo_box_get_line_height(combo_box) * combo_box->priv->n_lines + 8;
   } else {
-    req->height = breq.height;
+    natural->height = breq.height;
   }
-  req->width  = ereq.width + breq.width + areq.width;
+  natural->width  = ereq.width + breq.width + areq.width;
 
-  gtk_widget_set_size_request(combo_box->priv->entry, ereq.width, ereq.height);
-  gtk_widget_set_size_request(combo_box->priv->scrolled_window, ereq.width, ereq.height);
+  minimum->height = natural->height;
+  minimum->width = MINIMUM_WIDTH + breq.width + areq.width;
+
+  gtk_widget_set_size_request(combo_box->priv->entry, MINIMUM_WIDTH, ereq.height);
+  gtk_widget_set_size_request(combo_box->priv->scrolled_window, MINIMUM_WIDTH, ereq.height);
 }
 
 
