@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2025 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,10 +30,17 @@
 #include "perlscript.h"
 
 
-/********************7
+/********************
  * Type definitions *
  ********************/
-typedef void (*UpdateFunc)();
+typedef enum {
+  TRIGGER,
+  ALIAS,
+  MACRO,
+  TIMER,
+  HOOK,
+} ImportedObject;
+
 
 
 /***********************
@@ -48,12 +55,12 @@ static void          we_guied_export_selected_hooks(GString      *str,
                                                     GtkTreeModel *model,
                                                     GtkBuilder   *ui_builder);
 static void          we_guied_do_import(World *world, const gchar *filename);
-static void          we_guied_try_import(GSList      **oldlist,
-                                         GSList       *newlist,
-                                         gint         *pos,
-                                         UpdateFunc    update_func,
-                                         World        *world,
-                                         const gchar  *evt_name);
+static void          we_guied_try_import(GSList         **oldlist,
+                                         GSList          *newlist,
+                                         gint            *pos,
+                                         World           *world,
+                                         ImportedObject   type,
+                                         const gchar     *evt_name);
 static void          we_guied_try_import_vars(World *world, World *newworld);
 static gboolean     *we_guied_get_pointer_to_bool_value(gpointer object,
                                                         gint column);
@@ -401,75 +408,75 @@ we_guied_do_import(World *world, const gchar *filename)
   we_guied_try_import(&world->triggers,
                       newworld->triggers,
                       &world->trigger_pos,
-                      we_trigger_insert_trigger,
                       world,
+                      TRIGGER,
                       NULL);
   we_guied_try_import(&world->aliases,
                       newworld->aliases,
                       &world->alias_pos,
-                      (UpdateFunc) we_alias_insert_alias,
                       world,
+                      ALIAS,
                       NULL);
   we_guied_try_import(&world->macros,
                       newworld->macros,
                       &world->macro_pos,
-                      (UpdateFunc) we_macro_insert_macro,
                       world,
+                      MACRO,
                       NULL);
   we_guied_try_import(&world->timers,
                       newworld->timers,
                       &world->timer_pos,
-                      (UpdateFunc) we_timer_insert_timer,
                       world,
+                      TIMER,
                       NULL);
   we_guied_try_import_vars(world, newworld);
   we_guied_try_import(&world->hooks.OnConnect,
                       newworld->hooks.OnConnect,
                       &world->hooks.OnConnect_pos,
-                      (UpdateFunc) we_hook_insert_hook,
                       world,
+                      HOOK,
                       "OnConnect");
   we_guied_try_import(&world->hooks.OnDisconnect,
                       newworld->hooks.OnDisconnect,
                       &world->hooks.OnDisconnect_pos,
-                      (UpdateFunc) we_hook_insert_hook,
                       world,
+                      HOOK,
                       "OnDisconnect");
   we_guied_try_import(&world->hooks.OnReceivedText,
                       newworld->hooks.OnReceivedText,
                       &world->hooks.OnReceivedText_pos,
-                      (UpdateFunc) we_hook_insert_hook,
                       world,
+                      HOOK,
                       "OnReceivedText");
   we_guied_try_import(&world->hooks.OnSentCommand,
                       newworld->hooks.OnSentCommand,
                       &world->hooks.OnSentCommand_pos,
-                      (UpdateFunc) we_hook_insert_hook,
                       world,
+                      HOOK,
                       "OnSentCommand");
   we_guied_try_import(&world->hooks.OnGetFocus,
                       newworld->hooks.OnGetFocus,
                       &world->hooks.OnGetFocus_pos,
-                      (UpdateFunc) we_hook_insert_hook,
                       world,
+                      HOOK,
                       "OnGetFocus");
   we_guied_try_import(&world->hooks.OnLoseFocus,
                       newworld->hooks.OnLoseFocus,
                       &world->hooks.OnLoseFocus_pos,
-                      (UpdateFunc) we_hook_insert_hook,
                       world,
+                      HOOK,
                       "OnLoseFocus");
   we_guied_try_import(&world->hooks.OnCloseConnected,
                       newworld->hooks.OnCloseConnected,
                       &world->hooks.OnCloseConnected_pos,
-                      (UpdateFunc) we_hook_insert_hook,
                       world,
+                      HOOK,
                       "OnCloseConnected");
   we_guied_try_import(&world->hooks.OnServerData,
                       newworld->hooks.OnServerData,
                       &world->hooks.OnServerData_pos,
-                      (UpdateFunc) we_hook_insert_hook,
                       world,
+                      HOOK,
                       "OnServerData");
 
   /* This can only be done after the importing because it uses a Perl
@@ -501,12 +508,12 @@ we_guied_do_import(World *world, const gchar *filename)
 
 static
 void
-we_guied_try_import(GSList      **oldlist,
-                    GSList       *newlist,
-                    gint         *pos,
-                    UpdateFunc    update_func,
-                    World        *world,
-                    const gchar  *evt_name)
+we_guied_try_import(GSList         **oldlist,
+                    GSList          *newlist,
+                    gint            *pos,
+                    World           *world,
+                    ImportedObject   type,
+                    const gchar     *evt_name)
 {
   if (newlist) {
     GSList *last;
@@ -544,10 +551,22 @@ we_guied_try_import(GSList      **oldlist,
     for (listiter = newlist, i = first_pos;
          listiter != last;
          listiter = listiter->next, ++i) {
-      if (evt_name) {
-        update_func(world, evt_name, listiter->data, i);
-      } else {
-        update_func(world, listiter->data, i);
+      switch (type) {
+      case TRIGGER:
+        we_trigger_insert_trigger(world, listiter->data, i);
+        break;
+      case ALIAS:
+        we_alias_insert_alias(world, listiter->data, i);
+        break;
+      case MACRO:
+        we_macro_insert_macro(world, listiter->data, i);
+        break;
+      case TIMER:
+        we_timer_insert_timer(world, listiter->data, i);
+        break;
+      case HOOK:
+        we_hook_insert_hook(world, evt_name, listiter->data, i);
+        break;
       }
     }
   }
